@@ -17,7 +17,7 @@ class FileUploadMixin(object):
         data = open(filename, "rb").read()
         return self.new_storage_file(bucket=bucket, data=data)
 
-    def new_storage_file(self, bucket, data):
+    def new_storage_file(self, bucket, data, filename=None):
         """Stores the `file` to the container
 
         :param data: data to be stored
@@ -30,7 +30,11 @@ class FileUploadMixin(object):
         }
         headers = {}
         res = self._perform_request(
-            "post", url, files={"bucket": bucket, "file": data}, headers=headers
+            "post",
+            url,
+            files={"bucket": bucket, "file": data},
+            params={"filename": filename},
+            headers=headers,
         )
         return self._process_response(res, [201])
 
