@@ -5,6 +5,7 @@ import logging
 import re
 import tarfile
 import time
+from typing import Optional
 
 log = logging.getLogger(__name__)
 
@@ -15,7 +16,7 @@ class ExecutionError(Exception):
     pass
 
 
-class MachineLearningMixin(object):
+class MachineLearningMixin:
     def _inject_ml_models(self, config, ml_models, dereference=True):
         if ml_models:
             try:
@@ -34,7 +35,14 @@ class MachineLearningMixin(object):
     #
     # Machine Learning workflows
     #
-    def new_machinelearning_workflow(self, project_id, name, config, ml_models=None):
+    def new_machinelearning_workflow(
+        self,
+        project_id,
+        name,
+        config,
+        ml_models=None,
+        type=None,
+    ):
         """Create a new Machine Learning Workflow.
 
         :param project_id: Id of the Squirro project.
@@ -43,6 +51,8 @@ class MachineLearningMixin(object):
             Detailed documentation here: https://squirro.atlassian.net/wiki/spaces/DOC/pages/337215576/Squirro+Machine+Learning+Documentation  # noqa
         :param ml_models: Directory with ml_models to be uploaded into the workflow
             path
+        :param type: Optional parameter to define type of the Machine
+            learning workflow
         """
 
         base_url = "{}/v0/{}/projects/{}/machinelearning_workflows"
@@ -51,6 +61,8 @@ class MachineLearningMixin(object):
         url = base_url.format(self.topic_api_url, self.tenant, project_id)
 
         ml_workflow = {"name": name, "config": config}
+        if type:
+            ml_workflow["type"] = type
 
         # Inject token
         ml_workflow["squirro_token"] = self.refresh_token
@@ -121,7 +133,13 @@ class MachineLearningMixin(object):
         return {"data": res.content, "headers": res.headers}
 
     def modify_machinelearning_workflow(
-        self, project_id, ml_workflow_id, name=None, config=None, ml_models=None
+        self,
+        project_id,
+        ml_workflow_id,
+        name=None,
+        config=None,
+        ml_models=None,
+        type=None,
     ):
         """Modify an existing Machine Learning workflow.
 
@@ -132,6 +150,8 @@ class MachineLearningMixin(object):
             Detailed documentation here: https://squirro.atlassian.net/wiki/spaces/DOC/pages/337215576/Squirro+Machine+Learning+Documentation  # noqa
         :param ml_models: Directory with ml_models to be uploaded into the workflow
             path.
+        :param type: Optional parameter to define type of the Machine
+            learning workflow
         """
         base_url = "{}/v0/{}/projects/{}/machinelearning_workflows"
         headers = {"Content-Type": "application/json"}
@@ -146,6 +166,8 @@ class MachineLearningMixin(object):
             ml_workflow_update["name"] = name
         if config is not None:
             ml_workflow_update["config"] = config
+        if type:
+            ml_workflow_update["type"] = type
 
         url = "/".join([base_url, ml_workflow_id])
         url = url.format(self.topic_api_url, self.tenant, project_id)
@@ -207,6 +229,41 @@ class MachineLearningMixin(object):
             log.exception(e.error)
             return {"items": [], "error": e.error}
 
+    def clone_machinelearning_workflow(
+        self,
+        project_id: str,
+        ml_workflow_id: str,
+        name: Optional[str] = None,
+        type: Optional[str] = None,
+    ):
+        """
+        Clone the Machine Learning Workflow.
+
+        :param project_id: Id of the Squirro project.
+        :param ml_workflow_id: Id of the Machine Learning workflow.
+        :param name: Optional name of Machine learning workflow. If not
+            specified, the name of the workflow will be the same as the original one.
+        :param type: Optional type of Machine learning workflow. If not
+            specified, the type of the workflow will be the same as the original one.
+        """
+        url = (
+            f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}"
+            f"/machinelearning_workflows/{ml_workflow_id}/clone"
+        )
+
+        res = self._perform_request(
+            "post",
+            url,
+            data=json.dumps(
+                {
+                    "name": name,
+                    "type": type,
+                }
+            ),
+            headers={"Content-Type": "application/json"},
+        )
+        return self._process_response(res, [201])
+
     #
     # Machine Learning jobs
     #
