@@ -1,10 +1,4 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
-
 import json
-from builtins import object
 
 
 class ThemesMixin(object):
